@@ -48,7 +48,6 @@ describe 'openstack_extras::auth_file' do
           :service_token            => 'servicetoken',
           :service_endpoint         => 'http://127.0.0.2:5000/v3/',
           :username                 => 'myuser',
-          :tenant_name              => 'mytenant',
           :project_name             => 'myproject',
           :region_name              => 'myregion',
           :use_no_cache             => 'false',
@@ -85,7 +84,6 @@ describe 'openstack_extras::auth_file' do
           'export OS_SERVICE_TOKEN=\'servicetoken\'',
           'export OS_SERVICE_ENDPOINT=\'http://127.0.0.2:5000/v3/\'',
           'export OS_NO_CACHE=\'false\'',
-          'export OS_TENANT_NAME=\'mytenant\'',
           'export OS_PROJECT_NAME=\'myproject\'',
           'export OS_USERNAME=\'myuser\'',
           'export OS_PASSWORD=\'admin\'',
